<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_TW" version="2.0">
<context>
    <name>Badges</name>
    <message>
        <location filename="../qml/pages/Badges.qml" line="18"/>
        <source>BADGES</source>
        <translation>徽章</translation>
    </message>
</context>
<context>
    <name>Checkin</name>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="18"/>
        <source>CHECK-IN DETAILS</source>
        <translation>打卡內容</translation>
    </message>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="210"/>
        <source>TOTAL POINTS</source>
        <translation>總分</translation>
    </message>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="251"/>
        <source>EARNED BADGES</source>
        <translation>得到的徽章</translation>
    </message>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="273"/>
        <source>COMMENTS</source>
        <translation>留言</translation>
    </message>
</context>
<context>
    <name>CheckinDialog</name>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="22"/>
        <source>NEW CHECK-IN</source>
        <translation>新的打卡</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="48"/>
        <source>CHECK IN</source>
        <translation>打卡</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="57"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="100"/>
        <source>Whats on your mind?</source>
        <translation>在想什麼呢？</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="124"/>
        <source>Sharing options</source>
        <translation>分享選項</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="128"/>
        <source>Share with Friends</source>
        <translation>與朋友分享</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="136"/>
        <source>Post to Facebook</source>
        <translation>分享至 Facebook</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="144"/>
        <source>Post to Twitter</source>
        <translation>分享至 Twitter</translation>
    </message>
</context>
<context>
    <name>CheckinHistory</name>
    <message>
        <location filename="../qml/pages/CheckinHistory.qml" line="24"/>
        <source>CHECK-IN HISTORY</source>
        <translation>打卡紀錄</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinHistory.qml" line="64"/>
        <source>Load More</source>
        <translation>載入更多</translation>
    </message>
</context>
<context>
    <name>CommentDialog</name>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="26"/>
        <source>What is on your mind?</source>
        <translation>在想什麼呢？</translation>
    </message>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="38"/>
        <source>New awesome comment</source>
        <translation>新的留言</translation>
    </message>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="64"/>
        <source>Comment!</source>
        <translation>發文！</translation>
    </message>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="72"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>DebugSubmit</name>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="18"/>
        <source>DEBUG SUBMIT</source>
        <translation>除錯資料傳送</translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="34"/>
        <source>Thank you for submit!&lt;br&gt;This will be implemented soon!</source>
        <translation>感謝你的回報！&lt;br&gt;我們會盡快搞定的！</translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="53"/>
        <source>SUBMIT</source>
        <translation>送出</translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="61"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="92"/>
        <source>You can help me with Nelisquare development by submitting debug info.

The following information are going to be submitted:</source>
        <translation>你可以傳送除錯訊息來協助我開發 Nelisquare 。

下列的資訊將會被傳送：</translation>
    </message>
</context>
<context>
    <name>DebugWidget</name>
    <message>
        <location filename="../qml/components/DebugWidget.qml" line="14"/>
        <source>Unknown %1 event!</source>
        <translation>未知的 %1 事件！</translation>
    </message>
    <message>
        <location filename="../qml/components/DebugWidget.qml" line="47"/>
        <source>This event type is unknown.
You can help with resolution.</source>
        <translation>未知的事件型態。
你可以協助分析。</translation>
    </message>
</context>
<context>
    <name>FriendsFeed</name>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="44"/>
        <source>FRIENDS FEED</source>
        <translation>朋友動態</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="217"/>
        <source>RECENT</source>
        <translation>最新消息</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="230"/>
        <source>NEARBY</source>
        <translation>在我附近</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="251"/>
        <source>Load More</source>
        <translation>載入更多</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="398"/>
        <source>Sorry, Pages are not supported yet :(</source>
        <translation>抱歉，尚未支援這頁面 :(</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="468"/>
        <source>Sorry, no lists support yet :(</source>
        <translation>抱歉，尚未支援清單 :(</translation>
    </message>
</context>
<context>
    <name>LeaderBoard</name>
    <message>
        <location filename="../qml/pages/LeaderBoard.qml" line="19"/>
        <source>YOU ARE #</source>
        <translation>你是第 </translation>
    </message>
    <message>
        <location filename="../qml/pages/LeaderBoard.qml" line="63"/>
        <source>&lt;b&gt;%1 points&lt;/b&gt; %2 checkins</source>
        <translation>&lt;b&gt;%1 分&lt;/b&gt; %2 個打卡</translation>
    </message>
</context>
<context>
    <name>LikeBox</name>
    <message>
        <location filename="../qml/components/LikeBox.qml" line="33"/>
        <source>USER LIKES</source>
        <translation>按讚的使用者</translation>
    </message>
</context>
<context>
    <name>ListViewEx</name>
    <message>
        <location filename="../qml/components/ListViewEx.qml" line="9"/>
        <source>Pull and hold to refresh...</source>
        <translation>下拉即可更新...</translation>
    </message>
    <message>
        <location filename="../qml/components/ListViewEx.qml" line="10"/>
        <source>Release to refresh...</source>
        <translation>釋放立即更新...</translation>
    </message>
</context>
<context>
    <name>Login24sq</name>
    <message>
        <location filename="../qml/pages/Login24sq.qml" line="42"/>
        <source>Sign In to Foursquare</source>
        <translation>登入至 Foursquare</translation>
    </message>
</context>
<context>
    <name>Mayorships</name>
    <message>
        <location filename="../qml/pages/Mayorships.qml" line="19"/>
        <source>MAYORSHIPS</source>
        <translation>市長</translation>
    </message>
</context>
<context>
    <name>NotificationDialog</name>
    <message>
        <location filename="../qml/components/NotificationDialog.qml" line="36"/>
        <source>OK</source>
        <translation>確定</translation>
    </message>
</context>
<context>
    <name>Notifications</name>
    <message>
        <location filename="../qml/pages/Notifications.qml" line="24"/>
        <source>NOTIFICATIONS</source>
        <translation>通知</translation>
    </message>
    <message>
        <location filename="../qml/pages/Notifications.qml" line="51"/>
        <source>Mark all as read</source>
        <translation>全部標示為以獨</translation>
    </message>
    <message>
        <location filename="../qml/pages/Notifications.qml" line="58"/>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
</context>
<context>
    <name>PageWrapper</name>
    <message>
        <location filename="../qml/components/PageWrapper.qml" line="88"/>
        <source>Check updates</source>
        <translation>檢查更新</translation>
    </message>
    <message>
        <location filename="../qml/components/PageWrapper.qml" line="94"/>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../qml/components/PageWrapper.qml" line="100"/>
        <source>Exit</source>
        <translation>離開</translation>
    </message>
</context>
<context>
    <name>Photo</name>
    <message>
        <location filename="../qml/pages/Photo.qml" line="20"/>
        <source>PHOTO</source>
        <translation>相片</translation>
    </message>
</context>
<context>
    <name>PhotoAdd</name>
    <message>
        <location filename="../qml/pages/PhotoAdd.qml" line="17"/>
        <source>Select photo for upload</source>
        <translation>選擇要上傳的相片</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoAdd.qml" line="123"/>
        <source>Error uploading photo!</source>
        <translation>相片上傳錯誤！</translation>
    </message>
</context>
<context>
    <name>PhotoShareDialog</name>
    <message>
        <location filename="../qml/components/PhotoShareDialog.qml" line="37"/>
        <source>Selected photo</source>
        <translation>已選擇的相片</translation>
    </message>
    <message>
        <location filename="../qml/components/PhotoShareDialog.qml" line="59"/>
        <source>Sharing</source>
        <translation>分享</translation>
    </message>
    <message>
        <location filename="../qml/components/PhotoShareDialog.qml" line="63"/>
        <source>Public</source>
        <translation>公開</translation>
    </message>
    <message>
        <location filename="../qml/components/PhotoShareDialog.qml" line="70"/>
        <source>Facebook</source>
        <translation>Facebook</translation>
    </message>
    <message>
        <location filename="../qml/components/PhotoShareDialog.qml" line="77"/>
        <source>Twitter</source>
        <translation>Twitter</translation>
    </message>
    <message>
        <location filename="../qml/components/PhotoShareDialog.qml" line="92"/>
        <source>Upload photo</source>
        <translation>已上傳的相片</translation>
    </message>
    <message>
        <location filename="../qml/components/PhotoShareDialog.qml" line="105"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>PhotosBox</name>
    <message>
        <location filename="../qml/components/PhotosBox.qml" line="8"/>
        <source>PHOTOS</source>
        <translation>相片</translation>
    </message>
</context>
<context>
    <name>PhotosGallery</name>
    <message>
        <location filename="../qml/pages/PhotosGallery.qml" line="13"/>
        <source>VENUE PHOTOS</source>
        <translation>地盤相片</translation>
    </message>
</context>
<context>
    <name>SettingSlider</name>
    <message>
        <location filename="../qml/components/SettingSlider.qml" line="50"/>
        <source>Off</source>
        <translation>關閉</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../qml/pages/Settings.qml" line="13"/>
        <source>updating...</source>
        <translation>更新中...</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="21"/>
        <source>SETTINGS</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="53"/>
        <source>2012-2013 Basil Semuonov</source>
        <translation>2012-2013 Basil Semuonov</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="54"/>
        <source>Idea by Tommi Laukkanen</source>
        <translation>構想： Tommi Laukkanen</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="55"/>
        <source>Shout out to @knobtviker</source>
        <translation>感謝 @knobtviker</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="56"/>
        <source>Design by Kim Venetvirta</source>
        <translation>設計： Kim Venetvirta</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="57"/>
        <source>If any problems, tweet @basil_s</source>
        <translation>如果有任何問題，請發推特到 @basil_s</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="58"/>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="60"/>
        <source>Build</source>
        <translation>Build</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="62"/>
        <source>Powered by Foursquare</source>
        <translation>Powered by Foursquare</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="64"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="70"/>
        <location filename="../qml/pages/Settings.qml" line="115"/>
        <source>Reset settings</source>
        <translation>重設所有設定</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="71"/>
        <source>This action will erase all data including auth token, application settings and cache.</source>
        <translation>這動作將會清除所有資料，包括驗證、程式設定及快取。</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="72"/>
        <source>Yes, clear the data</source>
        <translation>是，清除資料</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="73"/>
        <source>No, thanks</source>
        <translation>不了</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="81"/>
        <source>Language</source>
        <translation>語言</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="109"/>
        <source>Notifications</source>
        <translation>通知</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="161"/>
        <source>UPDATES CHECK</source>
        <translation>檢查更新</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="186"/>
        <source>None</source>
        <translation>無</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="192"/>
        <source>Stable</source>
        <translation>穩定版</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="197"/>
        <source>Beta</source>
        <translation>Beta</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="203"/>
        <source>Alpha</source>
        <translation>Alpha</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="209"/>
        <source>INTERVALS</source>
        <translation>時間週期</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="213"/>
        <source>GPS Unlock timeout</source>
        <translation>GPS 解鎖逾時時間</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="214"/>
        <source>Instant</source>
        <translation>立即</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="214"/>
        <source>%1 secs(s)</source>
        <translation>%1 秒</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="214"/>
        <location filename="../qml/pages/Settings.qml" line="223"/>
        <source>Disabled</source>
        <translation>停用</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="222"/>
        <source>Feed autoupdate time</source>
        <translation>動態消息自動更新時間</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="223"/>
        <source>Off</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="223"/>
        <source>%1 min(s)</source>
        <translation>%1 分</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="231"/>
        <source>PERMISSIONS</source>
        <translation>權限</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="234"/>
        <source>Allow use of Location Data</source>
        <translation>允許使用定位資料</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="242"/>
        <source>Always run in background</source>
        <translation>總是在背景執行</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="250"/>
        <source>Enable notifications</source>
        <translation>啟用通知</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="258"/>
        <source>Feed at Home screen</source>
        <translation>主畫面動態消息</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="266"/>
        <source>Push notifications</source>
        <translation>通知推播</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="317"/>
        <source>COLOR THEME</source>
        <translation>佈景主題</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="336"/>
        <source>Light</source>
        <translation>亮色系</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="342"/>
        <source>Dark</source>
        <translation>暗色系</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="348"/>
        <source>SCREEN ORIENTATION</source>
        <translation>螢幕轉向</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="370"/>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="376"/>
        <source>Landscape</source>
        <translation>橫放</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="381"/>
        <source>Portrait</source>
        <translation>直立</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="387"/>
        <source>LANGUAGE</source>
        <translation>語言</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="398"/>
        <source>MAP PROVIDER</source>
        <translation>圖資提供者</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="421"/>
        <source>Nokia</source>
        <translation>Nokia</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="427"/>
        <source>Google</source>
        <translation>Google</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="432"/>
        <source>OSM</source>
        <translation>OSM</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="450"/>
        <source>IMAGE LOADING</source>
        <translation>相片載入</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="469"/>
        <source>All</source>
        <translation>所有</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="474"/>
        <source>Cached</source>
        <translation>已快取的</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="480"/>
        <source>INTEGRATION WITH APPS</source>
        <translation>整合其他 App</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="486"/>
        <source>Download MOLO.ME</source>
        <translation>下載 MOLO.ME</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="505"/>
        <source>MOLO.ME Photos</source>
        <translation>MOLO.ME 的相片</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="525"/>
        <source>APPLICATION CACHE</source>
        <translation>程式快取</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="533"/>
        <source>Clear</source>
        <translation>清除</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="545"/>
        <source>Size: %1</source>
        <translation>大小： %1</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="550"/>
        <source>AUTHENTICATION</source>
        <translation>驗證</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="553"/>
        <source>Reset authentication</source>
        <translation>重新驗證</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="574"/>
        <source>ACCESS RATE LIMIT</source>
        <translation>存取頻率限制</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="580"/>
        <source>API requests available: %1 / %2</source>
        <translation>可用 API 請求： %1 / %2</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="586"/>
        <source>You are low on X-RATE requests</source>
        <translation>你所剩的 X-RATE 請求次數不多</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="591"/>
        <source>DEBUG</source>
        <translation>除錯</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="597"/>
        <source>Options will be available soon</source>
        <translation>此功能會儘快開放</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="610"/>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="611"/>
        <source>Theme</source>
        <translation>佈景主題</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="612"/>
        <source>Service</source>
        <translation>服務</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="613"/>
        <source>Debug</source>
        <translation>除錯</translation>
    </message>
</context>
<context>
    <name>TipDialog</name>
    <message>
        <location filename="../qml/components/TipDialog.qml" line="40"/>
        <source>Write some cool tip here</source>
        <translation>在這新增些小提示吧</translation>
    </message>
    <message>
        <location filename="../qml/components/TipDialog.qml" line="66"/>
        <source>ADD</source>
        <translation>新增</translation>
    </message>
    <message>
        <location filename="../qml/components/TipDialog.qml" line="74"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>TipPage</name>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="22"/>
        <source>Usefull tip</source>
        <translation>有用的提示</translation>
    </message>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="149"/>
        <source>TIP PHOTO</source>
        <translation>相片提示</translation>
    </message>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="171"/>
        <source>Save tip</source>
        <translation>儲存提示</translation>
    </message>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="179"/>
        <source>Mark as done</source>
        <translation>標示已完成</translation>
    </message>
</context>
<context>
    <name>TipsList</name>
    <message>
        <location filename="../qml/pages/TipsList.qml" line="18"/>
        <source>TIPS LIST</source>
        <translation>提示列表</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="12"/>
        <source>New update available</source>
        <translation>有新的更新可用</translation>
    </message>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="13"/>
        <source>Version: %1&lt;br&gt;Type: %2&lt;br&gt;Build: %3&lt;br&gt;&lt;br&gt;Changelog: &lt;br&gt;%4</source>
        <translation>Version: %1&lt;br&gt;Type: %2&lt;br&gt;Build: %3&lt;br&gt;&lt;br&gt;更新紀錄： &lt;br&gt;%4</translation>
    </message>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="19"/>
        <source>Update!</source>
        <translation>更新！</translation>
    </message>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="20"/>
        <source>No, thanks</source>
        <translation>不了</translation>
    </message>
</context>
<context>
    <name>User</name>
    <message>
        <location filename="../qml/pages/User.qml" line="59"/>
        <source>USER DETAILS</source>
        <translation>用戶資料</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="270"/>
        <source>Add Friend</source>
        <translation>家為朋友</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="282"/>
        <source>Approve Friend</source>
        <translation>加入朋友</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="289"/>
        <source>Deny friend</source>
        <translation>拒絕邀請</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="301"/>
        <source>Remove Friend</source>
        <translation>移除朋友</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="314"/>
        <source>&lt;b&gt;SCORES&lt;/b&gt; (LAST 7 DAYS)</source>
        <translation>&lt;b&gt;分數&lt;/b&gt; （近七日內）</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="319"/>
        <source>BEST SCORE</source>
        <translation>最佳分數</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="377"/>
        <source>Badges</source>
        <translation>個徽章</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="412"/>
        <source>Checkins</source>
        <translation>個打卡</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="447"/>
        <source>Mayorships</source>
        <translation>個市長</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="482"/>
        <source>Friends</source>
        <translation>個朋友</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="517"/>
        <source>Photos</source>
        <translation>張相片</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="553"/>
        <source>Tips</source>
        <translation>個提示</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="569"/>
        <source>YOU ARE #</source>
        <translation>你是第 </translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="594"/>
        <source>&lt;b&gt;%1 points&lt;/b&gt; %2 checkins</source>
        <translation>&lt;b&gt;%1 分&lt;/b&gt; %2 個打卡</translation>
    </message>
</context>
<context>
    <name>UsersList</name>
    <message>
        <location filename="../qml/pages/UsersList.qml" line="21"/>
        <source>Loading...</source>
        <translation>載入中...</translation>
    </message>
    <message>
        <location filename="../qml/pages/UsersList.qml" line="30"/>
        <source>USER FRIENDS</source>
        <translation>朋友</translation>
    </message>
    <message>
        <location filename="../qml/pages/UsersList.qml" line="33"/>
        <source>LIKERS LIST</source>
        <translation>案讚名單</translation>
    </message>
</context>
<context>
    <name>Venue</name>
    <message>
        <location filename="../qml/pages/Venue.qml" line="131"/>
        <source>VENUE PHOTOS</source>
        <translation>地盤相片</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="239"/>
        <source>CHECK-IN HERE!</source>
        <translation>在這打卡！</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="261"/>
        <source>Venue doesn&apos;t have mayor yet!</source>
        <translation>這裡還沒有市長！</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="262"/>
        <source>is the mayor.</source>
        <translation>是市長。</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="262"/>
        <source>It could be you!</source>
        <translation>還不快搶！</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="263"/>
        <source>%1 checkins</source>
        <translation>%1 打卡</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="309"/>
        <source>BEST TIPS</source>
        <translation>最佳提示</translation>
    </message>
</context>
<context>
    <name>VenueEdit</name>
    <message>
        <location filename="../qml/pages/VenueEdit.qml" line="91"/>
        <source>Venue name</source>
        <translation>地盤名稱</translation>
    </message>
</context>
<context>
    <name>VenueMap</name>
    <message>
        <location filename="../qml/pages/VenueMap.qml" line="186"/>
        <source>GET ROUTE</source>
        <translation>計算路線</translation>
    </message>
</context>
<context>
    <name>VenuesList</name>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="21"/>
        <source>NEARBY VENUES</source>
        <translation>附近的地盤</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="47"/>
        <source>Add new venue</source>
        <translation>新增地盤</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="101"/>
        <source>Tap to search place...</source>
        <translation>點擊以搜尋地點...</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="112"/>
        <source>SEARCH</source>
        <translation>搜尋</translation>
    </message>
</context>
<context>
    <name>Welcome</name>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="29"/>
        <source>Welcome!</source>
        <translation>歡迎！</translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="46"/>
        <source>Please, login with Foursquare!</source>
        <translation>請登入 Foursquare ！</translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="53"/>
        <source>Login</source>
        <translation>登入</translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="67"/>
        <source>Foursquare privacy policy</source>
        <translation>Foursquare 隱私權政策</translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="81"/>
        <source>Nelisquare privacy policy</source>
        <translation>Nelisquare 隱私權政策</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="108"/>
        <source>Location data</source>
        <translation>訂位資料</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="109"/>
        <source>Nelisquare requires use of user location data. Data is needed to make geo-location services work properly.</source>
        <translation>Nelisquare 必須使用使用者定位資料以確保定位服務正常工作。</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="110"/>
        <source>Allow</source>
        <translation>允許</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="111"/>
        <source>Deny</source>
        <translation>拒絕</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="123"/>
        <source>Push notifications</source>
        <translation>推送通知</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="124"/>
        <source>Incoming push notifications are not supported at this version and are disabled by default.&lt;br/&gt;&lt;br/&gt;You will be promted again when they will be available at future versions.</source>
        <translation>新訊息的推送通知在此版本尚未正式啟用&lt;br/&gt;&lt;br/&gt;當此功能於未來版本啟用時你將會得到通知。</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="128"/>
        <source>OK</source>
        <translation>確定</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="161"/>
        <source>Check updates</source>
        <translation>檢查更新</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="167"/>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="173"/>
        <source>Exit</source>
        <translation>離開</translation>
    </message>
</context>
</TS>